@@ -14,17 +14,19 @@ var NAVTREEINDEX0 =
 "functions_vars.html":[2,2,2],
 "index.html":[],
 "index.html":[0],
-"index.html#soaphandler_0_1_0":[0,1,7],
-"index.html#soaphandler_0_2_0":[0,1,6],
-"index.html#soaphandler_0_2_1":[0,1,5],
-"index.html#soaphandler_0_2_2":[0,1,4],
-"index.html#soaphandler_0_2_3":[0,1,3],
-"index.html#soaphandler_0_2_4":[0,1,2],
-"index.html#soaphandler_0_2_5":[0,1,1],
-"index.html#soaphandler_0_2_6":[0,1,0],
+"index.html#soaphandler_0_1_0":[0,1,10],
+"index.html#soaphandler_0_2_0":[0,1,9],
+"index.html#soaphandler_0_2_1":[0,1,8],
+"index.html#soaphandler_0_2_2":[0,1,7],
+"index.html#soaphandler_0_2_3":[0,1,6],
+"index.html#soaphandler_0_2_4":[0,1,5],
+"index.html#soaphandler_0_2_5":[0,1,4],
+"index.html#soaphandler_0_2_6":[0,1,3],
+"index.html#soaphandler_0_2_7":[0,1,2],
+"index.html#soaphandler_0_3":[0,1,1],
+"index.html#soaphandler_0_3_1":[0,1,0],
 "index.html#soaphandler_relnotes":[0,1],
 "index.html#soaphandlerintro":[0,0],
-"namespace_soap_handler.html":[2,0,0],
 "namespace_soap_handler.html":[1,0,0],
 "namespaces.html":[1,0],
 "pages.html":[]
