@@ -1,6 +1,6 @@
 var class_w_s_d_l_1_1_namespaces =
 [
-    [ "constructor", "class_w_s_d_l_1_1_namespaces.html#a2040e55c9bbb5890d79103bc999d0c05", null ],
+    [ "constructor", "class_w_s_d_l_1_1_namespaces.html#aa4a47c67cc39481b581c8e2275699269", null ],
     [ "getInputNamespaceUri", "class_w_s_d_l_1_1_namespaces.html#af61ab4d514cabbd25d55af17f8ea30c6", null ],
     [ "getNamespaceUri", "class_w_s_d_l_1_1_namespaces.html#a3c8339b0c3f81be1f08f498c3861db0a", null ],
     [ "getOutputNamespaceHash", "class_w_s_d_l_1_1_namespaces.html#a500afae4405fcae49a7ba826620a36c6", null ],
@@ -8,7 +8,9 @@ var class_w_s_d_l_1_1_namespaces =
     [ "getOutputNamespaceUri", "class_w_s_d_l_1_1_namespaces.html#a0d9049f356d5d9cea04096e05c9f38b7", null ],
     [ "getReferencedNamespaceMap", "class_w_s_d_l_1_1_namespaces.html#a44809952e9976c18bfc73120ea33fea0", null ],
     [ "getTargetNamespaceInputPrefix", "class_w_s_d_l_1_1_namespaces.html#a274f309852c1b2d31fb278bf6d6c41ca", null ],
+    [ "getTargetNamespaceOutputPrefix", "class_w_s_d_l_1_1_namespaces.html#aff2096dbdc685dc442bf091cbc674209", null ],
     [ "getTargetNamespaceUri", "class_w_s_d_l_1_1_namespaces.html#a102eed39efb5dc634a2e4a9d9d31fb80", null ],
+    [ "getUniquePrefix", "class_w_s_d_l_1_1_namespaces.html#a3a01f451aba58a3e2b6aaf7e01b1f609", null ],
     [ "hasSoap11", "class_w_s_d_l_1_1_namespaces.html#ade5f5a0e41f23082c4415000c3b66f92", null ],
     [ "hasSoap12", "class_w_s_d_l_1_1_namespaces.html#a381ffac3e3dfc35d25a1f08bc3977a64", null ],
     [ "isSchema", "class_w_s_d_l_1_1_namespaces.html#a3aec01c559c2bec3f341281caa800898", null ],
@@ -17,17 +19,17 @@ var class_w_s_d_l_1_1_namespaces =
     [ "popTargetNamespace", "class_w_s_d_l_1_1_namespaces.html#aedfe3acf8b84b16fc1646d0fe9743224", null ],
     [ "pushDefaultNamespace", "class_w_s_d_l_1_1_namespaces.html#a7a3715012cf5b44da17589f5e5490b7a", null ],
     [ "pushTargetNamespace", "class_w_s_d_l_1_1_namespaces.html#a807f5fa93350b5a9624aaafc1e1f85b1", null ],
-    [ "registerNamespaceIntern", "class_w_s_d_l_1_1_namespaces.html#a401d0cca7df397e25953e2728ff0bd4a", null ],
+    [ "registerNamespaceIntern", "class_w_s_d_l_1_1_namespaces.html#aac88c4338e14158553b7be0e38bff032", null ],
     [ "translateOutputNamespacePrefix", "class_w_s_d_l_1_1_namespaces.html#a6bf9718166e1b72ae2fca177b8a75060", null ],
     [ "base_types", "class_w_s_d_l_1_1_namespaces.html#af291b41004490961eb364dc37415cccc", null ],
     [ "default_ns", "class_w_s_d_l_1_1_namespaces.html#ab1545502b12252fdb61c808a91295ee4", null ],
+    [ "DefaultPrefixes", "class_w_s_d_l_1_1_namespaces.html#a82db2548e7aba87ae427bc74c82a1964", null ],
     [ "dss", "class_w_s_d_l_1_1_namespaces.html#a7cd0780869c4d3ba96ba19f6eb73fb7b", null ],
     [ "hassoap11", "class_w_s_d_l_1_1_namespaces.html#aa771d0914c50ce1998dbb4cb388c1338", null ],
     [ "hassoap12", "class_w_s_d_l_1_1_namespaces.html#af6b4e0a39eff0df4e13094f1c067b2b4", null ],
     [ "imap", "class_w_s_d_l_1_1_namespaces.html#ad846883bae9789dc243dd7ec1d454cc8", null ],
     [ "imapr", "class_w_s_d_l_1_1_namespaces.html#a6be30485579b2bb3c85a517ef5a7eead", null ],
     [ "ns", "class_w_s_d_l_1_1_namespaces.html#a941105ebedcc92d0bceb2a7d5c695480", null ],
-    [ "nsn", "class_w_s_d_l_1_1_namespaces.html#a651d8c7c5905579c991b5dee74367495", null ],
     [ "nsr", "class_w_s_d_l_1_1_namespaces.html#a748f053a9adab9edae636b3b5c241707", null ],
     [ "nss", "class_w_s_d_l_1_1_namespaces.html#aac54bc1b69fe349374835843aaf9f608", null ],
     [ "target_ns", "class_w_s_d_l_1_1_namespaces.html#a8bd3f9295d74d2271a96264facb1d9fc", null ],
