@@ -4,13 +4,15 @@ var class_w_s_d_l_1_1_w_s_message =
     [ "deserializeAllPartData", "class_w_s_d_l_1_1_w_s_message.html#a36e4e9112a34c4204a2d1ff60f3112f1", null ],
     [ "deserializeData", "class_w_s_d_l_1_1_w_s_message.html#ae843c79a199d14d75552ea094f33dabb", null ],
     [ "deserializeRpc", "class_w_s_d_l_1_1_w_s_message.html#a7cb8a89e7965d9cf7f684c1c54817657", null ],
+    [ "getDataProviderType", "class_w_s_d_l_1_1_w_s_message.html#a8ac50963dc348fb9517583aca4afed88", null ],
+    [ "getValueFromHash", "class_w_s_d_l_1_1_w_s_message.html#a08b8b52aaea1889b1b549fcf61a9fe85", null ],
+    [ "getValueFromHash", "class_w_s_d_l_1_1_w_s_message.html#a0e4886c52fe881fb6269e36d0a44e29f", null ],
     [ "serializeAllPartData", "class_w_s_d_l_1_1_w_s_message.html#a30ee1d0d206a244260e04f600e877f35", null ],
     [ "serializeData", "class_w_s_d_l_1_1_w_s_message.html#a41ebb9eb711560d4c03ae70e34e828ed", null ],
-    [ "serializeDocument", "class_w_s_d_l_1_1_w_s_message.html#a5df0f58177180d3b16556825f71157ca", null ],
-    [ "serializeRpc", "class_w_s_d_l_1_1_w_s_message.html#ae8b437b1a90d56f01625ff87fc21a81a", null ],
-    [ "serializeRpcValue", "class_w_s_d_l_1_1_w_s_message.html#aa89cd9303a01004d54bf21348644f23c", null ],
+    [ "serializeDocument", "class_w_s_d_l_1_1_w_s_message.html#a2a65fe45febb2cb9fd672dd28876d693", null ],
+    [ "serializeRpc", "class_w_s_d_l_1_1_w_s_message.html#a56c60a966c8a572dbe83e53e3e044519", null ],
+    [ "serializeRpcValue", "class_w_s_d_l_1_1_w_s_message.html#a24499593a6a45ae41312763176676e43", null ],
     [ "args", "class_w_s_d_l_1_1_w_s_message.html#acaf3bbbef4407722741eabd51594ae64", null ],
     [ "pmap", "class_w_s_d_l_1_1_w_s_message.html#ad1c73edbcd6d274573d0a135eef42a2d", null ],
-    [ "private", "class_w_s_d_l_1_1_w_s_message.html#a13651cb05e587398bda084b85cc4f65a", null ],
     [ "tmap", "class_w_s_d_l_1_1_w_s_message.html#a1140fa352c8e2155076dda7177256630", null ]
 ];
\ No newline at end of file
