@@ -1,3 +1,27 @@
+/*
+ @licstart  The following is the entire license notice for the JavaScript code in this file.
+
+ The MIT License (MIT)
+
+ Copyright (C) 1997-2020 by Dimitri van Heesch
+
+ Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+ and associated documentation files (the "Software"), to deal in the Software without restriction,
+ including without limitation the rights to use, copy, modify, merge, publish, distribute,
+ sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
+
+ The above copyright notice and this permission notice shall be included in all copies or
+ substantial portions of the Software.
+
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+ BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ @licend  The above is the entire license notice for the JavaScript code in this file
+*/
 var NAVTREE =
 [
   [ "Qore XML Module", "index.html", [
@@ -19,6 +43,9 @@ var NAVTREE =
       [ "DEPRECATED", "index.html#DEPRECATED", null ]
     ] ],
     [ "Release Notes", "index.html#xmlreleasenotes", [
+      [ "xml Module Version 1.5.1", "index.html#xml151", null ],
+      [ "xml Module Version 1.5", "index.html#xml15", null ],
+      [ "xml Module Version 1.4.2", "index.html#xml142", null ],
       [ "xml Module Version 1.4.1", "index.html#xml141", null ],
       [ "xml Module Version 1.4", "index.html#xml14", null ],
       [ "xml Module Version 1.3.2", "index.html#xml132", null ],
@@ -30,8 +57,8 @@ var NAVTREE =
     [ "XML Generation Options", "xml_generation_opts.html", null ],
     [ "Deprecated List", "deprecated.html", null ],
     [ "Modules", "modules.html", "modules" ],
-    [ "Namespaces", null, [
-      [ "Namespace List", "namespaces.html", "namespaces" ],
+    [ "Namespaces", "namespaces.html", [
+      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
       [ "Namespace Members", "namespacemembers.html", [
         [ "All", "namespacemembers.html", null ],
         [ "Functions", "namespacemembers_func.html", null ],
@@ -52,8 +79,8 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-".html",
-"index.html#xml132"
+"annotated.html",
+"group__xml__functions.html#gaf9992355e68589537fd988a2b9a57852"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
