@@ -1,26 +1,27 @@
 /* -*- indent-tabs-mode: nil -*- */
 /*
- QoreXmlRpcReader.cpp
+    QoreXmlRpcReader.cpp
 
- Qore Programming Language
+    Qore Programming Language
 
- Copyright (C) 2003 - 2015 David Nichols
+    Copyright (C) 2003 - 2019 Qore Technologies, s.r.o.
 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Lesser General Public
- License as published by the Free Software Foundation; either
- version 2.1 of the License, or (at your option) any later version.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) any later version.
 
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Lesser General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
 
- You should have received a copy of the GNU Lesser General Public
- License along with this library; if not, write to the Free Software
- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+#include <qore/Qore.h>
 #include "QoreXmlRpcReader.h"
 
 #include "ql_xml.h"
@@ -33,9 +34,9 @@ static int xmlrpc_do_empty_value(Qore::Xml::intern::XmlRpcValue *v, const char*
    else if (!strcmp(name, "boolean"))
       v->set(false);
    else if (!strcmp(name, "struct"))
-      v->set(new QoreHashNode);
+      v->set(new QoreHashNode(autoTypeInfo));
    else if (!strcmp(name, "array"))
-      v->set(new QoreListNode);
+      v->set(new QoreListNode(autoTypeInfo));
    else if (!strcmp(name, "double") || !strcmp(name, "ex:float"))
       v->set(0.0f);
    else if (!strcmp(name, "dateTime.iso8601") || !strcmp(name, "ex:dateTime"))
@@ -54,7 +55,7 @@ static int xmlrpc_do_empty_value(Qore::Xml::intern::XmlRpcValue *v, const char*
 int QoreXmlRpcReader::getStruct(Qore::Xml::intern::XmlRpcValue *v, const QoreEncoding* data_ccsid, ExceptionSink* xsink) {
    int nt;
 
-   QoreHashNode* h = new QoreHashNode;
+   QoreHashNode* h = new QoreHashNode(autoTypeInfo);
    v->set(h);
 
    int member_depth = depth();
@@ -134,7 +135,7 @@ int QoreXmlRpcReader::getStruct(Qore::Xml::intern::XmlRpcValue *v, const QoreEnc
       if (readXmlRpc(xsink))
          break;
 
-      v->setPtr(h->getKeyValuePtr(member.getBuffer()));
+      v->setReference(&h->getKeyValueReference(member.getBuffer()));
 
       // if if was not an empty value element
       if (member_depth < depth()) {
@@ -179,7 +180,7 @@ int QoreXmlRpcReader::getParams(Qore::Xml::intern::XmlRpcValue *v, const QoreEnc
    int nt;
    int index = 0;
 
-   QoreListNode* l = new QoreListNode;
+   QoreListNode* l = new QoreListNode(autoTypeInfo);
    v->set(l);
 
    int array_depth = depth();
@@ -203,7 +204,7 @@ int QoreXmlRpcReader::getParams(Qore::Xml::intern::XmlRpcValue *v, const QoreEnc
       if (checkXmlRpcMemberName("param", xsink))
          return -1;
 
-      v->setPtr(l->get_entry_ptr(index++));
+      v->setReference(&l->getEntryReference(index++));
 
       // get next value tag or param close tag
       if (readXmlRpc(xsink))
@@ -379,7 +380,7 @@ int QoreXmlRpcReader::getDouble(Qore::Xml::intern::XmlRpcValue *v, ExceptionSink
       const char* str = constValue();
       if (str) {
          //printd(5, "** got float '%s'\n", str);
-         v->set(strtod(str, 0));
+         v->set(q_strtod(str));
       }
 
       // advance to next position
@@ -466,7 +467,7 @@ int QoreXmlRpcReader::getArray(Qore::Xml::intern::XmlRpcValue *v, const QoreEnco
    int nt;
    int index = 0;
 
-   QoreListNode* l = new QoreListNode;
+   QoreListNode* l = new QoreListNode(autoTypeInfo);
    v->set(l);
 
    int array_depth = depth();
@@ -513,7 +514,7 @@ int QoreXmlRpcReader::getArray(Qore::Xml::intern::XmlRpcValue *v, const QoreEnco
          if (checkXmlRpcMemberName("value", xsink))
             return -1;
 
-         v->setPtr(l->get_entry_ptr(index++));
+         v->setReference(&l->getEntryReference(index++));
 
          if (readXmlRpc(xsink))
             return -1;
